summaryrefslogtreecommitdiffstats
path: root/drivers/staging/tidspbridge/include/dspbridge/drv.h
diff options
context:
space:
mode:
authorRene Sapiens2010-07-10 04:24:03 +0200
committerGreg Kroah-Hartman2010-07-22 19:45:36 +0200
commit13b18c29ec01068dce4b266cc179d4e90e79d0e9 (patch)
tree1ce214748543368d31d4de8cdb4a30eef0c2e77b /drivers/staging/tidspbridge/include/dspbridge/drv.h
parentstaging: ti dspbridge: Rename words with camel case (diff)
downloadkernel-qcow2-linux-13b18c29ec01068dce4b266cc179d4e90e79d0e9.tar.gz
kernel-qcow2-linux-13b18c29ec01068dce4b266cc179d4e90e79d0e9.tar.xz
kernel-qcow2-linux-13b18c29ec01068dce4b266cc179d4e90e79d0e9.zip
staging: ti dspbridge: Rename words with camel case.
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== pPhysAddr to phys_addr pPhysicalAddress to physical_address ppIntfFxns to if_fxns pProcLoadStat to proc_load_stat pProcStat to proc_lstat ppSym to sym_val pRefData to ref_data pRef to ref preservedBit to preserved_bit pResult to result procID to proc_id pSectInfo to sect_inf pSrc to src pstrContent to str_content pstrDummyFile to str_dummy_file pstrExecFile to str_exec_file ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge/drv.h')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/drv.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/drv.h b/drivers/staging/tidspbridge/include/dspbridge/drv.h
index 604c15bda5f9..b43d22f8e512 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/drv.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/drv.h
@@ -451,7 +451,7 @@ extern void mem_ext_phys_pool_release(void);
* Parameters:
* byte_size: Number of bytes to allocate.
* ulAlign: Alignment Mask.
* pPhysicalAddress: Physical address of allocated memory.
* Returns:
* Pointer to a block of memory;
* NULL if memory couldn't be allocated, or if byte_size == 0.
@@ -463,7 +463,7 @@ extern void mem_ext_phys_pool_release(void);
* location of memory.
*/
extern void *mem_alloc_phys_mem(IN u32 byte_size,
- IN u32 ulAlign, OUT u32 *pPhysicalAddress);
+ IN u32 ulAlign, OUT u32 *physical_address);
/*
* ======== mem_free_phys_mem ========
@@ -472,7 +472,7 @@ extern void *mem_alloc_phys_mem(IN u32 byte_size,
* Parameters:
* pVirtualAddress: Pointer to virtual memory region allocated
* by mem_alloc_phys_mem().
* pPhysicalAddress: Pointer to physical memory region allocated
* by mem_alloc_phys_mem().
* byte_size: Size of the memory region allocated by mem_alloc_phys_mem().
* Returns:
@@ -484,14 +484,14 @@ extern void *mem_alloc_phys_mem(IN u32 byte_size,
* pVirtualAddress is no longer a valid pointer to memory.
*/
extern void mem_free_phys_mem(void *pVirtualAddress,
- u32 pPhysicalAddress, u32 byte_size);
+ u32 physical_address, u32 byte_size);
/*
* ======== MEM_LINEAR_ADDRESS ========
* Purpose:
* Get the linear address corresponding to the given physical address.
* Parameters:
- * pPhysAddr: Physical address to be mapped.
+ * phys_addr: Physical address to be mapped.
* byte_size: Number of bytes in physical range to map.
* Returns:
* The corresponding linear address, or NULL if unsuccessful.
@@ -451,7 +451,7 @@ extern void mem_ext_phys_pool_release(void);
* byte_size: Number of bytes to allocate.
* ulAlign: Alignment Mask.
- * pPhysicalAddress: Physical address of allocated memory.
+ * physical_address: Physical address of allocated memory.
* Returns:
* Pointer to a block of memory;
@@ -472,7 +472,7 @@ extern void *mem_alloc_phys_mem(IN u32 byte_size,
* pVirtualAddress: Pointer to virtual memory region allocated
* by mem_alloc_phys_mem().
- * pPhysicalAddress: Pointer to physical memory region allocated
+ * physical_address: Pointer to physical memory region allocated
* by mem_alloc_phys_mem().
* byte_size: Size of the memory region allocated by mem_alloc_phys_mem().